Index: Source/platform/ThemeTypes.h |
diff --git a/Source/platform/ThemeTypes.h b/Source/platform/ThemeTypes.h |
index 5bffca061c3f33814c73c21a39bdf6d8fd52bd66..0acba2fe24e4b4413e0b2cdc03c64703618297f5 100644 |
--- a/Source/platform/ThemeTypes.h |
+++ b/Source/platform/ThemeTypes.h |
@@ -29,16 +29,16 @@ |
namespace WebCore { |
enum ControlState { |
- HoverState = 1, |
- PressedState = 1 << 1, |
- FocusState = 1 << 2, |
- EnabledState = 1 << 3, |
- CheckedState = 1 << 4, |
- ReadOnlyState = 1 << 5, |
- WindowInactiveState = 1 << 7, |
- IndeterminateState = 1 << 8, |
- SpinUpState = 1 << 9, // Sub-state for HoverState and PressedState. |
- AllStates = 0xffffffff |
+ HoverControlState = 1, |
+ PressedControlState = 1 << 1, |
+ FocusControlState = 1 << 2, |
+ EnabledControlState = 1 << 3, |
+ CheckedControlState = 1 << 4, |
+ ReadOnlyControlState = 1 << 5, |
+ WindowInactiveControlState = 1 << 7, |
+ IndeterminateControlState = 1 << 8, |
+ SpinUpControlState = 1 << 9, // Sub-state for HoverControlState and PressedControlState. |
+ AllControlStates = 0xffffffff |
}; |
typedef unsigned ControlStates; |